@@ -14,7 +14,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with MALDIquantForeign. If not, see <http://www.gnu.org/licenses/>
+## along with MALDIquantForeign. If not, see <https://www.gnu.org/licenses/>
 
 .writeMzMlDocument <- function(x, file, id, encoding="utf-8", imsArgs=list()) {
   ## stop if file isn't writeable
@@ -22,6 +22,11 @@
     stop("No permissions to write into ", sQuote(file), "!")
   }
 
+  if (!MALDIquant:::.isMassObjectList(x)) {
+    stop("Only MALDIquant::MassSpectrum or MALDIquant::MassPeaks objects ",
+         "are supported!")
+  }
+
   isIms <- length(imsArgs)
 
   ## file handle
