@@ -14,7 +14,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with MALDIquantForeign. If not, see <http://www.gnu.org/licenses/>
+## along with MALDIquantForeign. If not, see <https://www.gnu.org/licenses/>
 
 #' Parse Ciphergen XML files.
 #'
@@ -26,9 +26,8 @@
 #' @return Returns a list with metadata and spectra.
 #'
 #' @author Sebastian Gibb \email{mail@@sebastiangibb.de}
-#' @rdname parseCiphergenXml
 #' @keywords internal
-#'
+#' @noRd
 .parseCiphergenXml <- function(file, ...) {
 
   ## metaData
@@ -62,7 +61,7 @@
   ## tof2mass
   ## mass = U*(A*(tof-t0)^2 + B)
   ## Calibration formula was taken from:
-  ## http://bioinformatics.mdanderson.org/Supplements/Datasets/KuererQC/scripts.zip
+  ## https://bioinformatics.mdanderson.org/Supplements/Datasets/KuererQC/scripts.zip
   ## file: ciphergenXMLreader.pl
   n <- 0:(length(intensity)-1)
   time <- metaData$spotCorrectionFactor*n/metaData$digitizerRate
@@ -71,5 +70,5 @@
             (sign(tof) * metaData$massCalibrationA * tof*tof +
              metaData$massCalibrationB)
 
-  return(list(spectrum=list(mass=mass, intensity=intensity), metaData=metaData))
+  list(spectrum=list(mass=mass, intensity=intensity), metaData=metaData)
 }
